@@ -2,11 +2,14 @@
 
 from .wraps import *
 from .quotedata import *
-#from .technical_analysis import *
+# from .technical_analysis import *
 import multiprocessing
 
-if multiprocessing.get_start_method() != 'spawn':
-    multiprocessing.set_start_method('spawn')
+try:
+    if multiprocessing.get_start_method() != 'spawn':
+        multiprocessing.set_start_method('spawn')
+except:
+    pass
 
 __version__ = '0.2'
 
@@ -14,4 +17,4 @@ __all__ = [
     'JQWraps',
     'QuoteData',
     '__version__'
-]
\ No newline at end of file
+]
