@@ -1,17 +1,22 @@
 # -*- coding: utf-8 -*-
 import multiprocessing
-import os
+import os, sys
 from functools import lru_cache, wraps
-from multiprocessing import shared_memory
+
 import threading
 
 import math
+from inspect import isfunction
+
 import numpy as np
 import pandas as pd
 
 from .technical_analysis import *
 from .utils import *
 
+if check_sharedmemory_support():
+    from multiprocessing import shared_memory
+
 
 def assert_quote_init(func):
     @wraps(func)
@@ -367,6 +372,10 @@ class QuoteData(object):
 
         shape = (len(df), 1 + len(cols_px) + len(cols_vm))
         multi_process = self._options.get('multi_process', False)
+        if multi_process and not check_sharedmemory_support():
+            multi_process = False
+            self.trace('shared memory not support, multi-process disabled')
+
         if multi_process:
             self.trace('rehabilitation within multi-process')
 
@@ -444,9 +453,13 @@ class QuoteData(object):
         cols_techansi = []
         indications = formatter_list(indications)
         for v in indications:
-            v = [v] if type(v) is str else list(v)
+            v = [v] if type(v) is str or isfunction(v) else list(v)
             c = v.pop(0)
-            func = globals().get(c)
+            if isfunction(c):
+                func = c
+                c = func.__name__
+            else:
+                func = globals().get(c)
             if not func:
                 print('%s is not exists.' % c)
                 continue
