@@ -1,9 +1,15 @@
 # -*- coding: utf-8 -*-
 import datetime
 import re
+import sys
 
 import time
 
+
+def check_sharedmemory_support():
+    return sys.version_info >= (3, 8)
+
+
 def formatter_st(v, default=None) -> time.struct_time:
     if v is None:
         v = default
